@@ -7,6 +7,7 @@ from doing.utils import (
     run_command,
     get_repo_name,
     to_snake_case,
+    remove_special_chars,
     get_az_devop_user_email,
     get_git_current_branch,
 )
@@ -59,7 +60,7 @@ def cmd_create_pr(
     cmd = f"az repos ref list --repository '{repo_name}' --query \"[?name=='refs/heads/master'].objectId\" "
     cmd += f"--org '{organization}' -p '{project}'"
     master_branch_object_id = run_command(cmd)[0]
-    branch_name = f"{work_item_id}_{to_snake_case(work_item_title)}"
+    branch_name = f"{work_item_id}_{to_snake_case(remove_special_chars(work_item_title))}"
     if branch_name in remote_branches:
         console.print(
             f"[dark_orange3]>[/dark_orange3] Remote branch '[cyan]{branch_name}[/cyan]' already exists, using that one"
@@ -112,7 +113,9 @@ def cmd_create_pr(
             reviewers = user_email
 
     if reviewers != "":
-        command += f"--reviewers '{reviewers}' "
+        # Azure wants the format --reviewers 'one' 'two' 'three'
+        az_reviewers = " ".join([f"'{x}'" for x in reviewers.split(" ")])
+        command += f"--reviewers {az_reviewers} "
 
     pr = run_command(command)
 
@@ -146,7 +149,7 @@ def explain_checkout(branch_name: str) -> None:
     """
     console.print("\tTo start work on the PR run:")
     console.print("\t[bright_black]git fetch origin[/bright_black]")
-    console.print(f"\t[bright_black]git checkout -b {branch_name} origin/{branch_name}[/bright_black]")
+    console.print(f"\t[bright_black]git checkout -b '{branch_name}' 'origin/{branch_name}'[/bright_black]")
 
 
 def git_checkout(branch_name: str, verbose: bool = True) -> None:
@@ -160,9 +163,9 @@ def git_checkout(branch_name: str, verbose: bool = True) -> None:
     if verbose:
         console.print(
             "\t[dark_orange3]$[/dark_orange3] Running command:",
-            f"[bright_black]git checkout -b {branch_name} origin/{branch_name}[/bright_black]",
+            f"[bright_black]git checkout -b '{branch_name}' 'origin/{branch_name}'[/bright_black]",
         )
-    os.system(f"git checkout -b {branch_name} origin/{branch_name}")
+    os.system(f"git checkout -b '{branch_name}' 'origin/{branch_name}'")
 
 
 def check_uncommitted_work() -> None:
