@@ -1,4 +1,4 @@
-from doing.utils import run_command, get_repo_name
+from doing.utils import run_command, get_repo_name, replace_user_aliases
 from rich.table import Table
 from rich.live import Live
 from rich.progress import track
@@ -9,34 +9,79 @@ from typing import List, Dict
 console = Console()
 
 
-def cmd_list(team: str, area: str, iteration: str, organization: str, project: str):
+def work_item_query(assignee: str, author: str, label: str, state: str, area: str, iteration: str):
+    """
+    Build query in wiql.
+
+    # More on 'work item query language' syntax:
+    # https://docs.microsoft.com/en-us/azure/devops/boards/queries/wiql-syntax?view=azure-devops
+    """
+    # ensure using user aliases
+    assignee = replace_user_aliases(assignee)
+    author = replace_user_aliases(author)
+
+    # Get all workitems
+    query = "SELECT [System.Id],[System.Title],[System.AssignedTo],[System.WorkItemType],[System.State]"
+    query += f"FROM WorkItems WHERE [System.AreaPath] = '{area}' "
+    # Filter on iteration. Note we use UNDER so that user can choose to provide teams path for all sprints.
+    query += f"AND [System.IterationPath] UNDER '{iteration}' "
+    if assignee:
+        query += f"AND [System.AssignedTo] = '{assignee}' "
+    if author:
+        query += f"AND [System.CreatedBy] = '{author}' "
+    if label:
+        for lab in label.split(" "):
+            query += f"AND [System.Tags] Contains '{lab}' "
+    if state == "open":
+        query += "AND ([System.State] = 'Active' OR [System.State] = 'New') "
+    if state == "closed":
+        query += "AND ([System.State] = 'Resolved' OR [System.State] = 'Closed') "
+    if state == "all":
+        query += "AND [System.State] <> 'Removed' "
+
+    # Ordering of results
+    query += "ORDER BY [System.CreatedDate] desc"
+    return query
+
+
+def cmd_list(
+    assignee: str,
+    author: str,
+    label: str,
+    state: str,
+    team: str,
+    area: str,
+    iteration: str,
+    organization: str,
+    project: str,
+) -> None:
     """
     Run `doing list` command.
     """
-    # Get all workitems
-    # Filter on iteration. Note we use UNDER so that user can choose to provide teams path for all sprints.
-    query = "SELECT [System.Id],[System.Title],[System.AssignedTo],[System.WorkItemType] "
-    query += "FROM WorkItems WHERE ([System.State] = 'Active' OR [System.State] = 'New') "
-    query += f"AND [System.IterationPath] UNDER '{iteration}' "
-    query += f"AND [System.AreaPath] = '{area}' "
+    # Get config settings
+    assignee = replace_user_aliases(assignee)
+    author = replace_user_aliases(author)
+
+    query = work_item_query(assignee, author, label, state, area, iteration)
     work_items = run_command(f'az boards query --wiql "{query}" --org "{organization}" -p "{project}"')
 
     workitem_prs = {}  # type: Dict
 
+    # Now for each work item we could get linked PRs
+    # However, APIs requests are slow, and most work items don't have a PR.
+    # Instead, we'll retrieve all active PRs and see which items are linked (less API calls)
+    repo_name = get_repo_name()
+    query = f"az repos pr list --repository '{repo_name}' --org '{organization}' -p '{project}' "
+    query += "--status 'active' --query '[].pullRequestId'"
+    active_pullrequest_ids = run_command(query)
+
     with Live(build_table(work_items, workitem_prs, iteration, False), refresh_per_second=4, console=console) as live:
 
-        # Now for each work item we could get linked PRs
-        # However, APIs requests are slow, and most work items don't have a PR.
-        # Instead, we'll retrieve all active PRs and see which items are linked (less API calls)
-        repo_name = get_repo_name()
-        query = f"az repos pr list --repository {repo_name} --org '{organization}' -p '{project}' "
-        query += "--status 'active' --query '[].pullRequestId'"
-        active_pullrequest_ids = run_command(query)
-
         # For each PR, get linked work items. Note that "az repos pr list --include-links" does not work :(
+        # Posted issue on bug here: https://github.com/Azure/azure-cli-extensions/issues/2946
         for pr_id in track(active_pullrequest_ids, description="Processing pull requests"):
             linked_workitems = run_command(
-                f"az repos pr work-item list --id {pr_id} --query '[].id' --org '{organization}'"
+                f"az repos pr work-item list --id {pr_id} --query '[].id' --org '{organization}'", allow_verbose=False
             )
             for work_item in linked_workitems:
                 if work_item in workitem_prs.keys():
