@@ -2,6 +2,8 @@ import os
 import sys
 import json
 import yaml
+import re
+import string
 from rich.console import Console
 import subprocess
 from dotenv import find_dotenv
@@ -15,12 +17,21 @@ install()
 console = Console()
 
 
-def to_snake_case(string):
+def to_snake_case(text: str) -> str:
     """
     Transform string to snake_case.
     """
-    string = string.lower().replace(" ", "_")
-    return string
+    text = re.sub(" +", " ", text)
+    text = text.lower().strip().replace(" ", "_")
+    return text
+
+
+def remove_special_chars(text: str) -> str:
+    """
+    Removes all special characters from a string.
+    """
+    chars = re.escape(string.punctuation)
+    return re.sub(r"[" + chars + "]", "", text)
 
 
 def shell_output(command) -> str:
@@ -132,10 +143,18 @@ def pprint(obj: Dict) -> None:
     print(json.dumps(obj, indent=2))
 
 
-def run_command(command: str):
+def run_command(command: str, allow_verbose=True):
     """
     Run a shell command.
+
+    Args:
+        command: The shell command.
+        allow_verbose: Allow printing. In some situations verbose
+            printing will lead to recursion error with rich.
     """
+    if allow_verbose and verbose_shell():
+        console.print(f"[bright_black]{command}[/bright_black]")
+
     process = subprocess.run(
         [command],
         stdin=subprocess.PIPE,
@@ -188,6 +207,9 @@ def replace_user_aliases(text: str) -> str:
     Replace alias with emailadres in a string.
     """
     words = text.split()
-    aliases = get_config("user_aliases")
+    aliases = get_config("user_aliases", "")
+
+    if not len(aliases):
+        return text
 
     return " ".join([aliases.get(word, word) for word in words])
